'use client';
import { login, signup } from '@/server/actions/auth';
import { zodResolver } from '@hookform/resolvers/zod';
import { useForm } from 'react-hook-form';
import { z } from 'zod';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import {
  Form,
  FormField,
  FormControl,
  FormDescription,
  FormLabel,
  FormMessage,
  FormItem,
} from '@/components/ui/form';
import { useRef } from 'react';
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { Separator } from '@/components/ui/separator';
import MicrosoftSignIn from '@/components/auth/microsoft/SignIn';
import AppleSignIn from '@/components/auth/apple/SignIn';

const formSchema = z.object({
  fullName: z.string().optional(),
  email: z.string().email('Must be a valid email!'),
  password: z.string().min(8, 'Must be at least 8 characters!'),
});

const LoginForm = () => {
  const formRef = useRef<HTMLFormElement>(null);

  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      fullName: '',
      email: '',
      password: '',
    },
  });

  // Create wrapper functions for the server actions
  const handleLogin = async () => {
    if (await form.trigger()) {
      const formData = new FormData(formRef.current!);
      await login(formData);
    }
  };

  const handleSignup = async () => {
    if (await form.trigger()) {
      const formData = new FormData(formRef.current!);
      await signup(formData);
    }
  };

  return (
    <Card
      className='flex flex-col items-center justify-center
        bg-gradient-to-br from-background via-zinc-50 to-gray-50
        dark:via-gray-950 dark:to-slate-950'
    >
      <CardHeader className='flex items-center justify-center'>
        <CardTitle>Sign In</CardTitle>
        <CardDescription>Log in or create an account.</CardDescription>
      </CardHeader>
      <CardContent>
        <Form {...form}>
          <form ref={formRef} className='space-y-4'>
            <FormField
              control={form.control}
              name='fullName'
              render={({ field }) => (
                <FormItem>
                  <FormLabel htmlFor='fullName'>Full Name</FormLabel>
                  <FormControl>
                    <Input id='fullName' type='text' {...field} />
                  </FormControl>
                  <FormDescription>
                    Full name is only required when signing up.
                  </FormDescription>
                  <FormMessage />
                </FormItem>
              )}
            />
            <FormField
              control={form.control}
              name='email'
              render={({ field }) => (
                <FormItem>
                  <FormLabel htmlFor='email'>Email</FormLabel>
                  <FormControl>
                    <Input id='email' type='email' {...field} required />
                  </FormControl>
                  <FormMessage />
                </FormItem>
              )}
            />
            <FormField
              control={form.control}
              name='password'
              render={({ field }) => (
                <FormItem>
                  <FormLabel>Password</FormLabel>
                  <FormControl>
                    <Input id='password' type='password' {...field} required />
                  </FormControl>
                  <FormMessage />
                </FormItem>
              )}
            />
            <div className='flex gap-4 justify-center items-center'>
              <Button
                type='button'
                className='w-5/12 font-semibold bg-gradient-to-r
                  from-primary via-primary to-primarydark
                  hover:from-primary hover:via-primarydark hover:to-primarydark'
                onClick={handleLogin}
              >
                Log in
              </Button>
              <Button
                type='button'
                className='w-5/12 font-semibold bg-gradient-to-l
                  from-primary via-primary to-primarydark
                  hover:from-primary hover:via-primarydark hover:to-primarydark'
                onClick={handleSignup}
              >
                Sign up
              </Button>
            </div>
          </form>
        </Form>
      </CardContent>
      <CardFooter className='flex flex-col items-center justify-center w-full'>
        <div className='flex flex-row items-center justify-between w-5/6'>
          <Separator className='w-5/12 h-0.5 rounded-3xl' />
          <p className='text-center text-muted-foreground font-semibold'>or</p>
          <Separator className='w-5/12 h-0.5 rounded-3xl' />
        </div>
        <div className='m-1'>
          <MicrosoftSignIn />
          <div className='my-2'>
            <AppleSignIn />
          </div>
        </div>
      </CardFooter>
    </Card>
  );
};

export default LoginForm;
